#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['warML', 'warML.sklearn']

package_data = \
{'': ['*']}

setup(name='warML',
      version='0.1',
      description='ML package for those tired of finding the proper syntax',
      author=None,
      author_email='Alexandre Rozier <alexandre.rozier@lilo.org>',
      url=None,
      packages=packages,
      package_data=package_data,
     )
